@@ -6,17 +6,12 @@ import click
 @click.command()
 @click.argument("script_filepath", type=click.Path(exists=True, file_okay=True, dir_okay=False))
 @click.argument("config_filepath", type=click.Path(exists=True, file_okay=True, dir_okay=False))
-@click.option(
-    "--local_rank", type=int, default=0, help="Local process rank for distributed computations",
-)
-def command(script_filepath: str, config_filepath: str, local_rank: int) -> None:
+def command(script_filepath: str, config_filepath: str) -> None:
     """Method to run experiment (defined by a script file)
 
     Args:
-        script_filepath (str): input script filepath
-        config_filepath (str): input configuration filepath
-        local_rank (int): local process rank for distributed computations.
-            See https://pytorch.org/docs/stable/distributed.html#launch-utility
+        script_filepath: input script filepath
+        config_filepath: input configuration filepath
     """
 
     # remove path to py_config_runner.py_config_runner module from sys.path
@@ -29,7 +24,7 @@ def command(script_filepath: str, config_filepath: str, local_rank: int) -> None
 
     from py_config_runner.runner import run_script
 
-    run_script(script_filepath, config_filepath, local_rank=local_rank)
+    run_script(script_filepath, config_filepath)
 
 
 def print_script_filepath() -> None:
